@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2015-12-30'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-01-21'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
+                       point
                        parse_cmdline
                        parse_options
                        format_completion
@@ -76,6 +77,48 @@ sub _add_single_quoted {
     $word;
 }
 
+$SPEC{point} = {
+    v => 1.1,
+    summary => 'Return line with point marked by a marker',
+    description => <<'_',
+
+This is a utility function useful for testing/debugging. `parse_cmdline()`
+expects a command-line and a cursor position (`$line`, `$point`). This routine
+expects `$line` with a marker character (by default it's the caret, `^`) and
+return (`$line`, `$point`) to feed to `parse_cmdline()`.
+
+Example:
+
+    point("^foo") # => ("foo", 0)
+    point("fo^o") # => ("foo", 2)
+
+_
+    args_as => 'array',
+    args => {
+        cmdline => {
+            summary => 'Command-line which contains a marker character',
+            schema => 'str*',
+            pos => 0,
+        },
+        marker => {
+            summary => 'Marker character',
+            schema => ['str*', len=>1],
+            default => '^',
+            pos => 1,
+        },
+    },
+    result_naked => 1,
+};
+sub point {
+    my ($line, $marker) = @_;
+    $marker //= '^';
+
+    my $point = index($line, $marker);
+    die "BUG: No marker '$marker' in line <$line>" unless $point >= 0;
+    $line =~ s/\Q$marker\E//;
+    ($line, $point);
+}
+
 $SPEC{parse_cmdline} = {
     v => 1.1,
     summary => 'Parse shell command-line for processing by completion routines',
@@ -176,11 +219,13 @@ sub parse_cmdline {
     die "$0: COMP_LINE not set, make sure this script is run under ".
         "bash completion (e.g. through complete -C)\n" unless defined $line;
 
+    #say "D:line=<$line> point=<$point>";
+
     my @words;
     my $cword;
     my $pos = 0;
     my $pos_min_ws = 0;
-    my $after_ws = 1;
+    my $after_ws = 1; # XXX what does this variable mean?
     my $chunk;
     my $add_blank;
     my $is_cur_word;
@@ -192,6 +237,7 @@ sub parse_cmdline {
                   \s+
               )!
                   $pos += length($1);
+                  #say "D: \$1=<$1> \$2=<$3> \$3=<$3> \$4=<$4> \$5=<$5> \$6=<$6> \$7=<$7> \$8=<$8> \$9=<$9>";
                   #say "D:<$1> pos=$pos, point=$point, cword=$cword, after_ws=$after_ws";
 
                   if ($2 || $5 || defined($8)) {
@@ -221,7 +267,8 @@ sub parse_cmdline {
                       if ($opts && $opts->{truncate_current_word} &&
                               $is_cur_word && $pos > $point) {
                           $chunk = substr(
-                              $chunk, 0, length($chunk)-($pos-$point));
+                              $chunk, 0, length($chunk)-($pos_min_ws-$point));
+                          #say "D:truncating current word to <$chunk>";
                       }
                       if ($after_ws) {
                           push @words, $chunk;
@@ -549,7 +596,7 @@ Complete::Bash - Completion module for bash shell
 
 =head1 VERSION
 
-This document describes version 0.24 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-12-30.
+This document describes version 0.25 of Complete::Bash (from Perl distribution Complete-Bash), released on 2016-01-21.
 
 =head1 DESCRIPTION
 
@@ -827,13 +874,38 @@ that contains extra information.
 
 Return value:  (hash)
 
-=head1 SEE ALSO (2)
 
-Other modules related to bash shell tab completion: L<Bash::Completion>,
-L<Getopt::Complete>. L<Term::Bash::Completion::Generator>
+=head2 point($cmdline, $marker) -> any
 
-Programmable Completion section in Bash manual:
-L<https://www.gnu.org/software/bash/manual/html_node/Programmable-Completion.html>
+Return line with point marked by a marker.
+
+This is a utility function useful for testing/debugging. C<parse_cmdline()>
+expects a command-line and a cursor position (C<$line>, C<$point>). This routine
+expects C<$line> with a marker character (by default it's the caret, C<^>) and
+return (C<$line>, C<$point>) to feed to C<parse_cmdline()>.
+
+Example:
+
+ point("^foo") # => ("foo", 0)
+ point("fo^o") # => ("foo", 2)
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<cmdline> => I<str>
+
+Command-line which contains a marker character.
+
+=item * B<marker> => I<str> (default: "^")
+
+Marker character.
+
+=back
+
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -841,7 +913,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-B
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Bash>.
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Bash>.
 
 =head1 BUGS
 
@@ -851,20 +923,26 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+
+L<Complete>
+
+Other modules related to bash shell tab completion: L<Bash::Completion>,
+L<Getopt::Complete>. L<Term::Bash::Completion::Generator>
+
+Programmable Completion section in Bash manual:
+L<https://www.gnu.org/software/bash/manual/html_node/Programmable-Completion.html>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 SEE ALSO
-
-
-L<Complete>
-
 =cut
